package com.kym.service;

import com.github.yulichang.base.MPJBaseService;
import com.kym.entity.Activity;
import com.kym.entity.queryParams.ActivityQueryParam;
import com.kym.entity.vo.ActivityVo;
import com.kym.entity.common.PageBean;

/**
 * <p>
 * 服务类
 * </p>
 *
 * @author skyline
 * @since 2023-10-18
 */
public interface ActivityService extends MPJBaseService<Activity> {

    void createActivity(ActivityVo activityVo);

    PageBean<Activity> listActivity(ActivityQueryParam params);

    ActivityVo activityDetail(String params);

    void terminateActivity(String activityId);
}
